@@ -257,17 +257,6 @@ static inline bool wrap_or_clip(Parameters &parameters, Bitmap<Pixelel> &image,
 /*****************/
 /*****************/
 
-static void click_func(GtkWidget *widget, gpointer data) {
-  if (data)
-    *((bool*)data) = true;
-}
-
-static gint delete_func(GtkWidget *widget, GdkEvent *event, gpointer data) {
-  if (data)
-    *((bool*)data) = true;
-  return TRUE;
-}
-
 static void click_func_quit(GtkWidget *widget, gpointer data) {
   if (data)
     *((bool*)data) = true;
